@@ -13,7 +13,7 @@ from suite_py.lib.handler import prompt_utils
 youtrack = YoutrackHandler()
 github = GithubHandler()
 logger = Logger()
-config = Config().load()
+config = Config()
 
 
 def entrypoint(project, card):
@@ -24,33 +24,39 @@ def entrypoint(project, card):
             issue = youtrack.get_issue(card)
         else:
             issue = youtrack.get_issue(ask_card())
-    except:
-        logger.error("Si e' verificato un problema recuperando la issue da youtrack. Controlla che il numero della issue e' corretto")
+    except Exception:
+        logger.error(
+            "Si e' verificato un problema recuperando la issue da youtrack. Controlla che il numero della issue e' corretto"
+        )
         sys.exit(-1)
 
     checkout_branch(project, issue)
 
     youtrack.assign_to(issue["id"], "me")
 
-    youtrack.update_state(issue["id"], config["youtrack"]["picked_state"])
+    youtrack.update_state(issue["id"], config.load()["youtrack"]["picked_state"])
+
 
 def ask_card():
     return prompt_utils.ask_questions_input(
-        'Inserisci il numero della issue youtrack:', config['user']['default_slug'])
+        "Inserisci il numero della issue youtrack:",
+        config.load()["user"]["default_slug"],
+    )
+
 
 def checkout_branch(project, issue):
-    branch_name = prompt_utils.ask_questions_input("Inserisci nome del branch: ", re.sub(
-        r'([\s\\.,~\^:\[\]"\'?]|[^\x00-\x7F])+', "-", issue["summary"]
-    ).lower())
+    branch_name = prompt_utils.ask_questions_input(
+        "Inserisci nome del branch: ",
+        re.sub(r'([\s\\.,~\^:\[\]"\'?]|[^\x00-\x7F])+', "-", issue["summary"]).lower(),
+    )
 
     parent_branch_name = prompt_utils.ask_questions_input(
-        "Inserisci branch iniziale: ", "master")
+        "Inserisci branch iniziale: ", "master"
+    )
 
     branch_type = issue["Type"].lower().replace(" ", "-")
 
-    branch_name = "{}/{}/{}".format(
-        branch_type, branch_name, issue["id"]
-    )
+    branch_name = f"{branch_type}/{branch_name}/{issue['id']}"
 
     git.checkout(project, parent_branch_name)
 
