@@ -29,12 +29,6 @@ def entrypoint(project, timeout):
         lock.set_timeout(timeout)
     stop_if_prod_locked(project, lock)
 
-    if prompt_utils.ask_confirm("Sono presenti migration?", default=False):
-        logger.error(
-            "Impossibile continuare con il deploy a causa di migration presenti. Chiedi ai devops di effettuare il deploy."
-        )
-        sys.exit(-1)
-
     git.fetch(project)
     repo = github.get_repo(project)
 
@@ -66,9 +60,9 @@ def entrypoint(project, timeout):
 
     deployed_cards_link = []
     issue_ids = youtrack.get_issue_ids(commits)
-
-    # if issue_ids:
-    #     logger.info(f"Imposto le card in {release_state}")
+    update_youtrack_state = prompt_utils.ask_confirm(
+        f"Vuoi spostare le card associate in {release_state}?", default=False
+    )
 
     for issue_id in issue_ids:
         try:
@@ -77,7 +71,9 @@ def entrypoint(project, timeout):
                 issue_id,
                 f"Deploy in produzione di {project} effettuato con la release {new_version}",
             )
-            # youtrack.update_state(issue_id, release_state)
+            if update_youtrack_state:
+                youtrack.update_state(issue_id, release_state)
+                logger.info(f"{issue_id} spostata in {release_state}")
         except Exception:
             logger.warning(
                 f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
@@ -148,11 +144,7 @@ def check_migrations_deploy(commits):
 
 
 def stop_if_prod_locked(project, lock):
-    try:
-        request = lock.status(project, "production")
-    except Exception:
-        logger.error("Impossibile contattare CaptainHook, stai usando la VPN?")
-        sys.exit(-1)
+    request = lock.status(project, "production")
 
     if request.status_code != 200:
         logger.error("Impossibile determinare lo stato del lock su master.")
