@@ -80,12 +80,13 @@ def create_pr(repo, branch_name, id_card=None):
         link = ""
         title = ask_for_title()
 
+    base_branch = ask_for_base_branch()
     pr_body = ask_for_description()
 
     body = f"{link} \n\n {pr_body}"
 
     try:
-        pr = github.create_pr(repo, branch_name, title, body)
+        pr = github.create_pr(repo, branch_name, title, body, base_branch)
         logger.info(f"Pull request numero {pr.number} creata! {pr.html_url}")
     except GithubException as e:
         logger.error("Errore durante la richiesta a GitHub: ")
@@ -100,6 +101,13 @@ def create_pr(repo, branch_name, id_card=None):
         ask_review.entrypoint(repo, config.load()["user"]["captainhook_timeout"])
 
 
+def ask_for_base_branch():
+    branch = prompt_utils.ask_questions_input(
+        "Inserisci il base branch della pull request: ", "master"
+    )
+    return branch
+
+
 def ask_for_description(pr_body=""):
     input(
         "Inserisci la description della pull request. Premendo invio si aprira l'editor di default"
