@@ -17,6 +17,9 @@ class SlackHandler(metaclass=Singleton):
     def __init__(self):
         self._client = slack.WebClient(token=tokens.slack)
 
+    def get_user(self):
+        return self._client.users_profile_get()
+
     def post(self, channel_config, text):
         channel = config.load()["user"].get(channel_config)
         if channel:
